FixedColumns examples - Styling

# FixedColumns example Styling

The examples in this section demonstrate how FixedColumns can be styling by CSS frameworks such as Bootstrap.

### Styling

- Complex headers
- Column visibility integration
- Server-side processing
- Individual column filtering
- Right-to-left text direction
- Bootstrap
- Bootstrap 4
- Foundation
- Semantic UI
- jQuery UI

Please refer to the DataTables documentation for full information about its API properties and methods.
Additionally, there are a wide range of extensions and plug-ins which extend the capabilities of DataTables.

DataTables designed and created by SpryMedia Ltd © 2007-2016
DataTables is licensed under the MIT license.